
//----------------------------------------------------------------------
// Copyright (c) 1990, 1999 Erick Engelke
void trim( char *s );

char * GetIniString( const char *filename, const char *section,
                     const char *key, const char *def );
int SetIniString( const char *filename, const char *section,
                  const char *key, const char *value );

DWORD GetIniDWORD( const char *filename, const char *section,
                   const char *key, DWORD def );

DWORD SetIniDWORD( const char *filename, const char *section,
                   const char *key, DWORD value );
